# coding: utf-8
from django.conf import settings

__author__ = 'Andrey Torsunov'
__contact__ = 'torsunov@bars-open.com'
__docformat__ = 'restructuredtext'

from django.contrib.auth.models import AnonymousUser
from m3.ui.actions import ActionPack, ActionController

from .helpers import remember_user, memorize_user
from .models import DataLog
from .enums import EventCode


orig_invoke = ActionController._invoke


class InvaderLogPack(ActionPack):

    def pre_run(self, request, context):
        memorize_user(request.user)

    def post_run(self, request, context, response):
        user = remember_user()
        if hasattr(response, 'data') and hasattr(response.data, 'title'):
            win = response.data
            DataLog.make_system_event(EventCode.WIN_OPEN, {
                'title': win.title
            })
        elif isinstance(request.user, AnonymousUser) and user != request.user:
            DataLog.make_system_event(EventCode.LOGOUT)
        elif isinstance(user, AnonymousUser) and user != request.user:
            DataLog.make_system_event(EventCode.LOGIN)


# Подмена оригинального метода, на метод который осуществляет инъекцию
# в InvaderLogPack в stack.
def invader_invoke(self, request, action, stack):
    stack.append(InvaderLogPack())
    return orig_invoke(self, request, action, stack)

if not settings.DATALOGGER_SHUTUP:
    ActionController._invoke = invader_invoke
